# Analysis API

## S-Parameter Analyzer

```{eval-rst}
.. autoclass:: prismo.analysis.sparameters.SParameterAnalyzer
   :members:
   :undoc-members:
```

## Export Functions

```{eval-rst}
.. autofunction:: prismo.analysis.sparameters.export_touchstone
.. autofunction:: prismo.analysis.sparameters.compute_group_delay
.. autofunction:: prismo.analysis.sparameters.compute_group_index
```
